/**
 * Copyright 2008 Bluestem Software LLC.  All Rights Reserved.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package org.bluestemsoftware.open.eoa.ext.dependency.maven20.util;

import org.apache.maven.artifact.versioning.ArtifactVersion;
import org.apache.maven.artifact.versioning.DefaultArtifactVersion;

public final class MavenUtils {

    /**
     * Compares versions specified on two <code>Dependency</code> objects and returns true if
     * proposed dependency is of a later version than existing dependency.
     * 
     * @param existing
     * @param proposed
     * @return true if 'proposed' is a later version than 'exisiting'. false if 'proposed' is
     *         same or older version than 'existing'.
     */
    @SuppressWarnings("unchecked")
    public static boolean isLaterVersion(String existingVersion, String proposedVersion) {

        ArtifactVersion existing = new DefaultArtifactVersion(existingVersion);
        ArtifactVersion proposed = new DefaultArtifactVersion(proposedVersion);
        return existing.compareTo(proposed) > 0;

    }

}
